==> polyxmass-bin_0.8.7.orig.tar.gz: polyxmass-bin-0.8.7/src/polyxedit-ui-mnmcompos.h <==
/* GNU polyxmass - the massist's program.
   -------------------------------------- 
   Copyright (C) 2000,2001,2002,2003,2004 Filippo Rusconi

   http://www.polyxmass.org

   This file is part of the "GNU polyxmass" project.
   
   The "GNU polyxmass" project is an official GNU project package (see
   www.gnu.org) released ---in its entirety--- under the GNU General
   Public License and was started at the Centre National de la
   Recherche Scientifique (FRANCE), that granted me the formal
   authorization to publish it under this Free Software License.

   This software is free software; you can redistribute it and/or
   modify it under the terms of the GNU  General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This software is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
   
   You should have received a copy of the GNU  General Public
   License along with this software; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/
#ifndef POLYXEDIT_UI_MNMCOMPOS_H
#define POLYXEDIT_UI_MNMCOMPOS_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "polyxedit-globals.h"
#include "polyxedit-editctxt.h"


GtkWidget *
polyxedit_mnmcompos_wnd_setup (PxmEditCtxt *editctxt);

gboolean
polyxedit_mnmcompos_wnd_setup_treeview (GtkWidget *window);

gboolean
polyxedit_mnmcompos_wnd_empty_list_monomer (GtkWidget *window);

gboolean
polyxedit_mnmcompos_wnd_update_list_monomer (GtkWidget *window);

void
polyxedit_mnmcompos_wnd_execute_button (GtkWidget *button,
					 gpointer data);
void
polyxedit_mnmcompos_wnd_update_sequence_region_button (GtkWidget *button,
						       gpointer data);




gint 
polyxedit_mnmcompos_wnd_delete_event (GtkWidget *window, 
					GdkEventAny *event, 
					gpointer data);

gint 
polyxedit_mnmcompos_wnd_destroy_event (GtkWidget *window, 
					GdkEventAny *event, 
					gpointer data);











#endif /*POLYXEDIT_UI_MNMCOMPOS_H */

==> polyxmass-bin_0.8.9.orig.tar.gz: polyxmass-bin-0.8.9/src/polyxedit-ui-mnmcompos.h <==
/* GNU polyxmass - the massist's program.
   -------------------------------------- 
   Copyright (C) 2000,2001,2002,2003,2004 Filippo Rusconi

   http://www.polyxmass.org

   This file is part of the "GNU polyxmass" project.
   
   The "GNU polyxmass" project is an official GNU project package (see
   www.gnu.org) released ---in its entirety--- under the GNU General
   Public License and was started at the Centre National de la
   Recherche Scientifique (FRANCE), that granted me the formal
   authorization to publish it under this Free Software License.

   This software is free software; you can redistribute it and/or
   modify it under the terms of the GNU  General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This software is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
   
   You should have received a copy of the GNU  General Public
   License along with this software; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/
#ifndef POLYXEDIT_UI_MNMCOMPOS_H
#define POLYXEDIT_UI_MNMCOMPOS_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "polyxedit-globals.h"
#include "polyxedit-editctxt.h"
#include "polyxmass-window-mngmt.h"


GtkWidget *
polyxedit_mnmcompos_wnd_setup (PxmEditCtxt *editctxt);

gboolean
polyxedit_mnmcompos_wnd_setup_treeview (GtkWidget *window);

gboolean
polyxedit_mnmcompos_wnd_empty_list_monomer (GtkWidget *window);

gboolean
polyxedit_mnmcompos_wnd_update_list_monomer (GtkWidget *window);

void
polyxedit_mnmcompos_wnd_execute_button (GtkWidget *button,
					 gpointer data);
void
polyxedit_mnmcompos_wnd_update_sequence_region_button (GtkWidget *button,
						       gpointer data);



/* REPORTING FUNCTIONS.
 */
gchar *
polyxedit_mnmcompos_wnd_make_report (PxmReportOpt* reportopt,
				     PxmWinMngmt* winmngmt);

gchar *
polyxedit_mnmcompos_wnd_make_report_text_format (PxmReportOpt* reportopt,
						 PxmWinMngmt* winmngmt);

gchar *
polyxedit_mnmcompos_wnd_make_report_latex_format (PxmReportOpt* reportopt,
						  PxmWinMngmt* winmngmt);




/* WINDOW LIFE-CYCLE FUNCTIONS.
 */
void
polyxedit_mnmcompos_wnd_really_close (GtkWidget *window);


gint 
polyxedit_mnmcompos_wnd_delete_event (GtkWidget *window, 
					GdkEventAny *event, 
					gpointer data);

gint 
polyxedit_mnmcompos_wnd_destroy_event (GtkWidget *window, 
					GdkEventAny *event, 
					gpointer data);











#endif /*POLYXEDIT_UI_MNMCOMPOS_H */
